@@ -121,19 +121,19 @@ inherited_item_openapi_schema = {
 @skip_py36
 def test_inherited_item_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == inherited_item_openapi_schema
 
 
 @skip_py36
 def test_post_extended_item():
     response = client.post("/items/", json={"name": "Foo", "age": 5})
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"item": {"name": "Foo", "age": 5}}
 
 
 @skip_py36
 def test_post_item():
     response = client.post("/items/", json={"name": "Foo"})
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"item": {"name": "Foo"}}
